.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`measure`
======================
.. automodule:: skimage.measure

.. currentmodule:: skimage.measure
.. autosummary::

   skimage.measure.approximate_polygon
   skimage.measure.block_reduce
   skimage.measure.compare_mse
   skimage.measure.compare_nrmse
   skimage.measure.compare_psnr
   skimage.measure.compare_ssim
   skimage.measure.find_contours
   skimage.measure.grid_points_in_poly
   skimage.measure.inertia_tensor
   skimage.measure.inertia_tensor_eigvals
   skimage.measure.label
   skimage.measure.marching_cubes
   skimage.measure.marching_cubes_classic
   skimage.measure.marching_cubes_lewiner
   skimage.measure.mesh_surface_area
   skimage.measure.moments
   skimage.measure.moments_central
   skimage.measure.moments_coords
   skimage.measure.moments_coords_central
   skimage.measure.moments_hu
   skimage.measure.moments_normalized
   skimage.measure.perimeter
   skimage.measure.points_in_poly
   skimage.measure.profile_line
   skimage.measure.ransac
   skimage.measure.regionprops
   skimage.measure.regionprops_table
   skimage.measure.shannon_entropy
   skimage.measure.subdivide_polygon

   skimage.measure.CircleModel
   skimage.measure.EllipseModel
   skimage.measure.LineModelND


approximate_polygon
-------------------

.. autofunction:: skimage.measure.approximate_polygon


.. include:: skimage.measure.approximate_polygon.examples

block_reduce
------------

.. autofunction:: skimage.measure.block_reduce


.. include:: skimage.measure.block_reduce.examples

compare_mse
-----------

.. autofunction:: skimage.measure.compare_mse


.. include:: skimage.measure.compare_mse.examples

compare_nrmse
-------------

.. autofunction:: skimage.measure.compare_nrmse


.. include:: skimage.measure.compare_nrmse.examples

compare_psnr
------------

.. autofunction:: skimage.measure.compare_psnr


.. include:: skimage.measure.compare_psnr.examples

compare_ssim
------------

.. autofunction:: skimage.measure.compare_ssim


.. include:: skimage.measure.compare_ssim.examples

find_contours
-------------

.. autofunction:: skimage.measure.find_contours


.. include:: skimage.measure.find_contours.examples

grid_points_in_poly
-------------------

.. autofunction:: skimage.measure.grid_points_in_poly


.. include:: skimage.measure.grid_points_in_poly.examples

inertia_tensor
--------------

.. autofunction:: skimage.measure.inertia_tensor


.. include:: skimage.measure.inertia_tensor.examples

inertia_tensor_eigvals
----------------------

.. autofunction:: skimage.measure.inertia_tensor_eigvals


.. include:: skimage.measure.inertia_tensor_eigvals.examples

label
-----

.. autofunction:: skimage.measure.label


.. include:: skimage.measure.label.examples

marching_cubes
--------------

.. autofunction:: skimage.measure.marching_cubes


.. include:: skimage.measure.marching_cubes.examples

marching_cubes_classic
----------------------

.. autofunction:: skimage.measure.marching_cubes_classic


.. include:: skimage.measure.marching_cubes_classic.examples

marching_cubes_lewiner
----------------------

.. autofunction:: skimage.measure.marching_cubes_lewiner


.. include:: skimage.measure.marching_cubes_lewiner.examples

mesh_surface_area
-----------------

.. autofunction:: skimage.measure.mesh_surface_area


.. include:: skimage.measure.mesh_surface_area.examples

moments
-------

.. autofunction:: skimage.measure.moments


.. include:: skimage.measure.moments.examples

moments_central
---------------

.. autofunction:: skimage.measure.moments_central


.. include:: skimage.measure.moments_central.examples

moments_coords
--------------

.. autofunction:: skimage.measure.moments_coords


.. include:: skimage.measure.moments_coords.examples

moments_coords_central
----------------------

.. autofunction:: skimage.measure.moments_coords_central


.. include:: skimage.measure.moments_coords_central.examples

moments_hu
----------

.. autofunction:: skimage.measure.moments_hu


.. include:: skimage.measure.moments_hu.examples

moments_normalized
------------------

.. autofunction:: skimage.measure.moments_normalized


.. include:: skimage.measure.moments_normalized.examples

perimeter
---------

.. autofunction:: skimage.measure.perimeter


.. include:: skimage.measure.perimeter.examples

points_in_poly
--------------

.. autofunction:: skimage.measure.points_in_poly


.. include:: skimage.measure.points_in_poly.examples

profile_line
------------

.. autofunction:: skimage.measure.profile_line


.. include:: skimage.measure.profile_line.examples

ransac
------

.. autofunction:: skimage.measure.ransac


.. include:: skimage.measure.ransac.examples

regionprops
-----------

.. autofunction:: skimage.measure.regionprops


.. include:: skimage.measure.regionprops.examples

regionprops_table
-----------------

.. autofunction:: skimage.measure.regionprops_table


.. include:: skimage.measure.regionprops_table.examples

shannon_entropy
---------------

.. autofunction:: skimage.measure.shannon_entropy


.. include:: skimage.measure.shannon_entropy.examples

subdivide_polygon
-----------------

.. autofunction:: skimage.measure.subdivide_polygon


.. include:: skimage.measure.subdivide_polygon.examples


:class:`CircleModel`
--------------------


.. autoclass:: CircleModel
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.measure.CircleModel.examples


:class:`EllipseModel`
---------------------


.. autoclass:: EllipseModel
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.measure.EllipseModel.examples


:class:`LineModelND`
--------------------


.. autoclass:: LineModelND
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.measure.LineModelND.examples

